# -*- coding:utf-8 -*-

# Blender asset_management_2_8 Add-on
# Copyright (C) 2018 Legigan Jeremy AKA Pistiwique
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# <pep8 compliant>


import bpy
import re

from bpy.types import Operator, PropertyGroup

from bpy.props import StringProperty, PointerProperty, BoolProperty


class AsturiasToolsProperties(PropertyGroup):
    mat_to_replace = StringProperty(
            name="Mat To Replace",
            default="",
            )

    mat_to_assign = StringProperty(
            name="Mat To Assign",
            default="",
            )

    on_selection = BoolProperty(
            name="On selection",
            default=False,
            description="Replace the material only for the selected objects"
            )


class ASTURIASTOOLS_OT_create_groups(Operator):
    ''' Create and name groups from selected objects '''
    bl_idname = "asturiastools.create_groups"
    bl_label = "Create groups"
    bl_options = {'REGISTER'}

    @classmethod
    def poll(cls, context):
        return context.selected_objects

    def execute(self, context):
        D = bpy.data

        for obj in context.selected_objects:
            if D.groups.find(obj.name) != -1:
                continue
            gp = D.groups.new(obj.name)
            gp.objects.link(obj)

        return {'FINISHED'}


class ASTURIASTOOLS_OT_replace_material(Operator):
    '''  '''
    bl_idname = 'asturiastools.replace_material'
    bl_label = "Replace Material"
    bl_options = {'REGISTER'}

    @classmethod
    def poll(cls, context):
        asturias = context.window_manager.asturias
        return (asturias.mat_to_replace and asturias.mat_to_assign)


    def replace_material(self, obj):
        for mat in obj.data.materials:
            if not self.asturias.mat_to_replace in mat.name:
                continue
            obj.material_slots[mat.name].material = bpy.data.materials[self.asturias.mat_to_assign]

    def execute(self, context):
        self.asturias = context.window_manager.asturias
        datablock = bpy.context.selected_objects if self.asturias.on_selection else\
            bpy.context.scene.objects

        for obj in datablock:
            if not hasattr(obj.data, "materials"):
                continue
            self.replace_material(obj)

        return {'FINISHED'}


CLASSES = [
    ASTURIASTOOLS_OT_create_groups,
    ASTURIASTOOLS_OT_replace_material,
    AsturiasToolsProperties
    ]


def register():
    for cls in CLASSES:
        bpy.utils.register_class(cls)

    bpy.types.WindowManager.asturias = PointerProperty(
            type=AsturiasToolsProperties)

def unregister():
    del bpy.types.WindowManager.asturias

    for cls in CLASSES:
        bpy.utils.unregister_class(cls)